@@ -136,9 +136,9 @@ class R3sponse(object):
 				if " " in formats: formats = formats.replace(" ","")
 				else: break
 			formats = formats.split(",")
-			param_format = Formats.get(parameter, serialize=False)
+			param_format = Formats.get(parameter, serialize=True)
 			if param_format not in formats:
-				return self.error_response(f"Incorrect parameter [{name}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
+				return self.error_response(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
 		return self.success_response(f"Succesfully checked parameter [{name}].")
 	def check_parameters(self, parameters={"parameter":None}, empty_value=None):
 		response = self.default_response()
@@ -287,7 +287,8 @@ class ResponseObject(object):
 		delattr(self, key)
 	# string format.
 	def __str__(self):
-		return json.dumps(self.dict(), indent=4)
+		return self.dict(serializable=True)
+		return json.dumps(self.dict(serializable=True), indent=4)
 		if isinstance(self, dict):
 			return json.dumps(self, indent=4)
 		else:
